aboutsummaryrefslogtreecommitdiffstats
path: root/drivers
diff options
context:
space:
mode:
authorJoel Bodenmann <joel.bodenmann@hevs.ch>2012-11-10 00:05:01 +0100
committerJoel Bodenmann <joel.bodenmann@hevs.ch>2012-11-10 00:05:01 +0100
commit87b6d98055afff7c46bd6bdd7db7ba7c1d8e7a57 (patch)
tree515085fe2b901604f1e88c6645583827ee3922b1 /drivers
parent995c9835c282e8904ff918e325f0491249bdcc89 (diff)
downloaduGFX-87b6d98055afff7c46bd6bdd7db7ba7c1d8e7a57.tar.gz
uGFX-87b6d98055afff7c46bd6bdd7db7ba7c1d8e7a57.tar.bz2
uGFX-87b6d98055afff7c46bd6bdd7db7ba7c1d8e7a57.zip
renamed touchpad into touchscreen
Diffstat (limited to 'drivers')
-rw-r--r--drivers/touchpad/ADS7843/readme.txt8
-rw-r--r--drivers/touchpad/ADS7843/touchpad_lld.mk6
-rw-r--r--drivers/touchpad/XPT2046/readme.txt8
-rw-r--r--drivers/touchpad/XPT2046/touchpad_lld.mk6
-rw-r--r--drivers/touchscreen/ADS7843/readme.txt8
-rw-r--r--drivers/touchscreen/ADS7843/touchscreen_lld.c (renamed from drivers/touchpad/XPT2046/touchpad_lld.c)96
-rw-r--r--drivers/touchscreen/ADS7843/touchscreen_lld.mk6
-rw-r--r--drivers/touchscreen/ADS7843/touchscreen_lld_config.h (renamed from drivers/touchpad/ADS7843/touchpad_lld_config.h)20
-rw-r--r--drivers/touchscreen/XPT2046/readme.txt8
-rw-r--r--drivers/touchscreen/XPT2046/touchscreen_lld.c (renamed from drivers/touchpad/ADS7843/touchpad_lld.c)96
-rw-r--r--drivers/touchscreen/XPT2046/touchscreen_lld.mk6
-rw-r--r--drivers/touchscreen/XPT2046/touchscreen_lld_config.h (renamed from drivers/touchpad/XPT2046/touchpad_lld_config.h)20
12 files changed, 144 insertions, 144 deletions
diff --git a/drivers/touchpad/ADS7843/readme.txt b/drivers/touchpad/ADS7843/readme.txt
deleted file mode 100644
index 90eadc32..00000000
--- a/drivers/touchpad/ADS7843/readme.txt
+++ /dev/null
@@ -1,8 +0,0 @@
-To use this driver:
-
-1. Add in your halconf.h:
- a) #define GFX_USE_TOUCHPAD TRUE
-
-2. To your makefile add the following lines:
- include $(GFXLIB)/drivers/touchpadADS7843/touchpad_lld.mk
-
diff --git a/drivers/touchpad/ADS7843/touchpad_lld.mk b/drivers/touchpad/ADS7843/touchpad_lld.mk
deleted file mode 100644
index 6aaa44ee..00000000
--- a/drivers/touchpad/ADS7843/touchpad_lld.mk
+++ /dev/null
@@ -1,6 +0,0 @@
-# List the required driver.
-GFXSRC += $(GFXLIB)/drivers/touchpad/ADS7843/touchpad_lld.c
-
-# Required include directories
-GFXINC += $(GFXLIB)/drivers/touchpad/ADS7843
-
diff --git a/drivers/touchpad/XPT2046/readme.txt b/drivers/touchpad/XPT2046/readme.txt
deleted file mode 100644
index baccebe8..00000000
--- a/drivers/touchpad/XPT2046/readme.txt
+++ /dev/null
@@ -1,8 +0,0 @@
-To use this driver:
-
-1. Add in your halconf.h:
- a) #define GFX_USE_TOUCHPAD TRUE
-
-2. To your makefile add the following lines:
- include $(GFXLIB)/drivers/touchpad/XPT2046/touchpad_lld.mk
-
diff --git a/drivers/touchpad/XPT2046/touchpad_lld.mk b/drivers/touchpad/XPT2046/touchpad_lld.mk
deleted file mode 100644
index 8d662a74..00000000
--- a/drivers/touchpad/XPT2046/touchpad_lld.mk
+++ /dev/null
@@ -1,6 +0,0 @@
-# List the required driver.
-GFXSRC += $(GFXLIB)/drivers/touchpad/XPT2046/touchpad_lld.c
-
-# Required include directories
-GFXINC += $(GFXLIB)/drivers/touchpad/XPT2046
-
diff --git a/drivers/touchscreen/ADS7843/readme.txt b/drivers/touchscreen/ADS7843/readme.txt
new file mode 100644
index 00000000..85f40da5
--- /dev/null
+++ b/drivers/touchscreen/ADS7843/readme.txt
@@ -0,0 +1,8 @@
+To use this driver:
+
+1. Add in your halconf.h:
+ a) #define GFX_USE_TOUCHSCREEN TRUE
+
+2. To your makefile add the following lines:
+ include $(GFXLIB)/drivers/touchscreen/ADS7843/touchscreen_lld.mk
+
diff --git a/drivers/touchscreen/ADS7843/touchscreen_lld.mk b/drivers/touchscreen/ADS7843/touchscreen_lld.mk
new file mode 100644
index 00000000..c58f6647
--- /dev/null
+++ b/drivers/touchscreen/ADS7843/touchscreen_lld.mk
@@ -0,0 +1,6 @@
+# List the required driver.
+GFXSRC += $(GFXLIB)/drivers/touchscreen/ADS7843/touchscreen_lld.c
+
+# Required include directories
+GFXINC += $(GFXLIB)/drivers/touchscreen/ADS7843
+
diff --git a/drivers/touchpad/ADS7843/touchpad_lld_config.h b/drivers/touchscreen/ADS7843/touchscreen_lld_config.h
index 5ed1981c..5769c288 100644
--- a/drivers/touchpad/ADS7843/touchpad_lld_config.h
+++ b/drivers/touchscreen/ADS7843/touchscreen_lld_config.h
@@ -19,27 +19,27 @@
*/
/**
- * @file drivers/touchpad/ADS7843/touchpad_lld_config.h
- * @brief Touchpad Driver subsystem low level driver.
+ * @file drivers/touchscreen/ADS7843/touchscreen_lld_config.h
+ * @brief Touchscreen Driver subsystem low level driver.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
-#ifndef _TOUCHPAD_LLD_CONFIG_H
-#define _TOUCHPAD_LLD_CONFIG_H
+#ifndef TOUCHSCREEN_LLD_CONFIG_H
+#define TOUCHSCREEN_LLD_CONFIG_H
-#if GFX_USE_TOUCHPAD /*|| defined(__DOXYGEN__)*/
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver hardware support. */
/*===========================================================================*/
-#define TOUCHPAD_HAS_IRQ TRUE
-#define TOUCHPAD_HAS_PRESSURE FALSE
+#define TOUCHSCREEN_HAS_IRQ TRUE
+#define TOUCHSCREEN_HAS_PRESSURE FALSE
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
-#endif /* _TOUCHPAD_LLD_CONFIG_H */
+#endif /* TOUCHSCREEN_LLD_CONFIG_H */
/** @} */
diff --git a/drivers/touchscreen/XPT2046/readme.txt b/drivers/touchscreen/XPT2046/readme.txt
new file mode 100644
index 00000000..a81caf67
--- /dev/null
+++ b/drivers/touchscreen/XPT2046/readme.txt
@@ -0,0 +1,8 @@
+To use this driver:
+
+1. Add in your halconf.h:
+ a) #define GFX_USE_TOUCHSCREEN TRUE
+
+2. To your makefile add the following lines:
+ include $(GFXLIB)/drivers/touchscreen/XPT2046/touchscreen_lld.mk
+
diff --git a/drivers/touchscreen/XPT2046/touchscreen_lld.mk b/drivers/touchscreen/XPT2046/touchscreen_lld.mk
new file mode 100644
index 00000000..39d5caf9
--- /dev/null
+++ b/drivers/touchscreen/XPT2046/touchscreen_lld.mk
@@ -0,0 +1,6 @@
+# List the required driver.
+GFXSRC += $(GFXLIB)/drivers/touchscreen/XPT2046/touchscreen_lld.c
+
+# Required include directories
+GFXINC += $(GFXLIB)/drivers/touchscreen/XPT2046
+
diff --git a/drivers/touchpad/XPT2046/touchpad_lld_config.h b/drivers/touchscreen/XPT2046/touchscreen_lld_config.h
index a503d2b7..1bb8718e 100644
--- a/drivers/touchpad/XPT2046/touchpad_lld_config.h
+++ b/drivers/touchscreen/XPT2046/touchscreen_lld_config.h
@@ -19,27 +19,27 @@
*/
/**
- * @file drivers/touchpad/XPT2046/touchpad_lld_config.h
- * @brief Touchppad Driver subsystem low level driver.
+ * @file drivers/touchscreen/XPT2046/touchscreen_lld_config.h
+ * @brief Touchscreen Driver subsystem low level driver.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
-#ifndef _TOUCHPAD_LLD_CONFIG_H
-#define _TOUCHPAD_LLD_CONFIG_H
+#ifndef TOUCHSCREEN_LLD_CONFIG_H
+#define TOUCHSCREEN_LLD_CONFIG_H
-#if GFX_USE_TOUCHPAD /*|| defined(__DOXYGEN__)*/
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver hardware support. */
/*===========================================================================*/
-#define TOUCHPAD_HAS_IRQ TRUE
-#define TOUCHPAD_HAS_PRESSURE TRUE
+#define TOUCHSCREEN_HAS_IRQ TRUE
+#define TOUCHSCREEN_HAS_PRESSURE TRUE
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
-#endif /* _TOUCHPAD_LLD_CONFIG_H */
+#endif /* TOUCHSCREEN_LLD_CONFIG_H */
/** @} */
diff --git a/drivers/touchpad/XPT2046/touchpad_lld.c b/drivers/touchscreen/ADS7843/touchscreen_lld.c
index 8be23b07..98e25383 100644
--- a/drivers/touchpad/XPT2046/touchpad_lld.c
+++ b/drivers/touchscreen/ADS7843/touchscreen_lld.c
@@ -19,18 +19,18 @@
*/
/**
* @file drivers/touchpad/XPT2046/touchpad_lld.c
* @brief Touchpad Driver subsystem low level driver source.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
#include "ch.h"
#include "hal.h"
-#include "touchpad.h"
+#include "touchscreen.h"
-#if GFX_USE_TOUCHPAD /*|| defined(__DOXYGEN__)*/
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver local definitions. */
@@ -44,8 +44,8 @@
/* Driver local variables. */
/*===========================================================================*/
#if !defined(__DOXYGEN__)
- /* Local copy of the current touchpad driver */
- static const TOUCHPADDriver *tpDriver;
+ /* Local copy of the current touchscreen driver */
+ static const TouchscreenDriver *tsDriver;
static uint16_t sampleBuf[7];
#endif
@@ -65,24 +65,24 @@
/* ---- Required Routines ---- */
/**
* @brief Low level Touchpad driver initialization.
*
* @param[in] tp The touchpad driver struct
*
* @notapi
*/
-void tp_lld_init(const TOUCHPADDriver *tp) {
- tpDriver = tp;
+void ts_lld_init(const TouchscreenDriver *ts) {
+ tsDriver = ts;
- if(tpDriver->direct_init)
- spiStart(tpDriver->spip, tpDriver->spicfg);
+ if(tsDriver->direct_init)
+ spiStart(tsDriver->spip, tsDriver->spicfg);
}
/**
* @brief Reads a conversion from the touchpad
*
* @param[in] cmd The command bits to send to the touchpad
*
* @return The read value 12-bit right-justified
*
@@ -91,14 +91,14 @@ void tp_lld_init(const TOUCHPADDriver *tp) {
*
* @notapi
*/
-uint16_t tp_lld_read_value(uint8_t cmd) {
+uint16_t ts_lld_read_value(uint8_t cmd) {
static uint8_t txbuf[3] = {0};
static uint8_t rxbuf[3] = {0};
uint16_t ret;
txbuf[0] = cmd;
- spiExchange(tpDriver->spip, 3, txbuf, rxbuf);
+ spiExchange(tsDriver->spip, 3, txbuf, rxbuf);
ret = (rxbuf[1] << 5) | (rxbuf[2] >> 3);
@@ -106,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
* @brief 7-point median filtering code for touchpad samples
*
* @note This is an internally used routine only.
*
* @notapi
*/
-static void tp_lld_filter(void) {
+static void ts_lld_filter(void) {
uint16_t temp;
int i,j;
for(i = 0; i < 4; i++) {
- for(j=i; j < 7; j++) {
+ for(j = i; j < 7; j++) {
if(sampleBuf[i] > sampleBuf[j]) {
/* Swap the values */
temp = sampleBuf[i];
@@ -135,37 +135,37 @@ static void tp_lld_filter(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_x(void) {
+uint16_t ts_lld_read_x(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0xD1);
+ ts_lld_read_value(0xD1);
for(i = 0; i < 7; i++) {
- sampleBuf[i]=tp_lld_read_value(0xD1);
+ sampleBuf[i] = ts_lld_read_value(0xD1);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0xD0);
+ ts_lld_read_value(0xD0);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
@@ -175,43 +175,43 @@ uint16_t tp_lld_read_x(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_y(void) {
+uint16_t ts_lld_read_y(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0x91);
+ ts_lld_read_value(0x91);
for(i = 0; i < 7; i++) {
- sampleBuf[i] = tp_lld_read_value(0x91);
+ sampleBuf[i] = ts_lld_read_value(0x91);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0x90);
+ ts_lld_read_value(0x90);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#ifdef SPI_USE_MUTUAL_EXCLUSION
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
/* ---- Optional Routines ---- */
-#if TOUCHPAD_HAS_IRQ || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_IRQ || defined(__DOXYGEN__)
/*
* @brief for checking if touchpad is pressed or not.
*
@@ -219,23 +219,23 @@ uint16_t tp_lld_read_y(void) {
*
* @notapi
*/
- uint8_t tp_lld_irq(void) {
- return (!palReadPad(tpDriver->tpIRQPort, tpDriver->tpIRQPin));
+ uint8_t ts_lld_irq(void) {
+ return (!palReadPad(tsDriver->tsIRQPort, tsDriver->tsIRQPin));
}
#endif
-#if TOUCHPAD_HAS_PRESSURE || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_PRESSURE || defined(__DOXYGEN__)
/*
* @brief Reads out the Z direction / pressure.
*
* @notapi
*/
- uint16_t tp_lld_read_z(void) {
+ uint16_t ts_lld_read_z(void) {
/* ToDo */
return 42;
}
#endif
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
/** @} */
@@ -19,18 +19,18 @@
*/
/**
- * @file drivers/touchpad/XPT2046/touchpad_lld.c
- * @brief Touchpad Driver subsystem low level driver source.
+ * @file drivers/touchscreen/ADS7843/touchscreen_lld.c
+ * @brief Touchscreen Driver subsystem low level driver source.
*
@@ -65,24 +65,24 @@
/* ---- Required Routines ---- */
/**
- * @brief Low level Touchpad driver initialization.
+ * @brief Low level touchscreen driver initialization.
*
@@ -65,24 +65,24 @@
*
- * @param[in] tp The touchpad driver struct
+ * @param[in] ts The touchscreen driver
*
* @notapi
@@ -65,24 +65,24 @@
}
/**
- * @brief Reads a conversion from the touchpad
+ * @brief Reads a conversion from the touchscreen
*
@@ -65,24 +65,24 @@
*
- * @param[in] cmd The command bits to send to the touchpad
+ * @param[in] cmd The command bits to send to the touchscreen
*
* @return The read value 12-bit right-justified
@@ -106,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
- * @brief 7-point median filtering code for touchpad samples
+ * @brief 7-point median filtering code for touchscreen samples
*
* @note This is an internally used routine only.
diff --git a/drivers/touchpad/ADS7843/touchpad_lld.c b/drivers/touchscreen/XPT2046/touchscreen_lld.c
index 8b30f4f3..90bf0032 100644
--- a/drivers/touchpad/ADS7843/touchpad_lld.c
+++ b/drivers/touchscreen/XPT2046/touchscreen_lld.c
@@ -19,18 +19,18 @@
*/
/**
* @file drivers/touchpad/ADS7843/touchpad_lld.c
* @brief Touchpad Driver subsystem low level driver source.
*
- * @addtogroup TOUCHPAD
+ * @addtogroup TOUCHSCREEN
* @{
*/
#include "ch.h"
#include "hal.h"
-#include "touchpad.h"
+#include "touchscreen.h"
-#if GFX_USE_TOUCHPAD /*|| defined(__DOXYGEN__)*/
+#if GFX_USE_TOUCHSCREEN /*|| defined(__DOXYGEN__)*/
/*===========================================================================*/
/* Driver local definitions. */
@@ -45,7 +45,7 @@
/*===========================================================================*/
#if !defined(__DOXYGEN__)
/* Local copy of the current touchpad driver */
- static const TOUCHPADDriver *tpDriver;
+ static const TouchscreenDriver *tsDriver;
static uint16_t sampleBuf[7];
#endif
@@ -65,24 +65,24 @@
/* ---- Required Routines ---- */
/**
* @brief Low level Touchpad driver initialization.
*
* @param[in] tp The touchpad driver
*
* @notapi
*/
-void tp_lld_init(const TOUCHPADDriver *tp) {
- tpDriver = tp;
+void ts_lld_init(const TouchscreenDriver *ts) {
+ tsDriver = ts;
- if(tpDriver->direct_init)
- spiStart(tpDriver->spip, tpDriver->spicfg);
+ if(tsDriver->direct_init)
+ spiStart(tsDriver->spip, tsDriver->spicfg);
}
/**
* @brief Reads a conversion from the touchpad
*
* @param[in] cmd The command bits to send to the touchpad
*
* @return The read value 12-bit right-justified
*
@@ -91,14 +91,14 @@ void tp_lld_init(const TOUCHPADDriver *tp) {
*
* @notapi
*/
-uint16_t tp_lld_read_value(uint8_t cmd) {
+uint16_t ts_lld_read_value(uint8_t cmd) {
static uint8_t txbuf[3] = {0};
static uint8_t rxbuf[3] = {0};
uint16_t ret;
txbuf[0] = cmd;
- spiExchange(tpDriver->spip, 3, txbuf, rxbuf);
+ spiExchange(tsDriver->spip, 3, txbuf, rxbuf);
ret = (rxbuf[1] << 5) | (rxbuf[2] >> 3);
@@ -106,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
* @brief 7-point median filtering code for touchpad samples
*
* @note This is an internally used routine only.
*
* @notapi
*/
-static void tp_lld_filter(void) {
+static void ts_lld_filter(void) {
uint16_t temp;
int i,j;
for(i = 0; i < 4; i++) {
- for(j=i; j < 7; j++) {
+ for(j = i; j < 7; j++) {
if(sampleBuf[i] > sampleBuf[j]) {
/* Swap the values */
temp = sampleBuf[i];
@@ -135,37 +135,37 @@ static void tp_lld_filter(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_x(void) {
+uint16_t ts_lld_read_x(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0xD1);
+ ts_lld_read_value(0xD1);
for(i = 0; i < 7; i++) {
- sampleBuf[i]=tp_lld_read_value(0xD1);
+ sampleBuf[i] = ts_lld_read_value(0xD1);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0xD0);
+ ts_lld_read_value(0xD0);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
@@ -175,67 +175,67 @@ uint16_t tp_lld_read_x(void) {
*
* @notapi
*/
-uint16_t tp_lld_read_y(void) {
+uint16_t ts_lld_read_y(void) {
int i;
#if defined(SPI_USE_MUTUAL_EXCLUSION)
- spiAcquireBus(tpDriver->spip);
+ spiAcquireBus(tsDriver->spip);
#endif
- TOUCHPAD_SPI_PROLOGUE();
- palClearPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_PROLOGUE();
+ palClearPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
/* Discard the first conversion - very noisy and keep the ADC on hereafter
* till we are done with the sampling. Note that PENIRQ is disabled.
*/
- tp_lld_read_value(0x91);
+ ts_lld_read_value(0x91);
for(i = 0; i < 7; i++) {
- sampleBuf[i] = tp_lld_read_value(0x91);
+ sampleBuf[i] = ts_lld_read_value(0x91);
}
/* Switch on PENIRQ once again - perform a dummy read */
- tp_lld_read_value(0x90);
+ ts_lld_read_value(0x90);
- palSetPad(tpDriver->spicfg->ssport, tpDriver->spicfg->sspad);
- TOUCHPAD_SPI_EPILOGUE();
+ palSetPad(tsDriver->spicfg->ssport, tsDriver->spicfg->sspad);
+ TOUCHSCREEN_SPI_EPILOGUE();
#ifdef SPI_USE_MUTUAL_EXCLUSION
- spiReleaseBus(tpDriver->spip);
+ spiReleaseBus(tsDriver->spip);
#endif
/* Find the median - use selection sort */
- tp_lld_filter();
+ ts_lld_filter();
return sampleBuf[3];
}
/* ---- Optional Routines ---- */
-#if TOUCHPAD_HAS_IRQ || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_IRQ || defined(__DOXYGEN__)
/*
* @brief for checking if touchpad is pressed or not.
*
* @return 1 if pressed / 0 if not pressed
*
* @notapi
*/
- uint8_t tp_lld_irq(void) {
- return (!palReadPad(tpDriver->tpIRQPort, tpDriver->tpIRQPin));
+ uint8_t ts_lld_irq(void) {
+ return (!palReadPad(tsDriver->tsIRQPort, tsDriver->tsIRQPin));
}
#endif
-#if TOUCHPAD_HAS_PRESSURE || defined(__DOXYGEN__)
+#if TOUCHSCREEN_HAS_PRESSURE || defined(__DOXYGEN__)
/*
* @brief Reads out the Z direction / pressure.
*
* @notapi
*/
- uint16_t tp_lld_read_z(void) {
+ uint16_t ts_lld_read_z(void) {
/* ToDo */
return 42;
}
#endif
-#endif /* GFX_USE_TOUCHPAD */
+#endif /* GFX_USE_TOUCHSCREEN */
/** @} */
@@ -19,18 +19,18 @@
*/
/**
- * @file drivers/touchpad/ADS7843/touchpad_lld.c
- * @brief Touchpad Driver subsystem low level driver source.
+ * @file drivers/touchscreen/XPT2046/touchscreen_lld.c
+ * @brief Touchscreen Driver subsystem low level driver source.
*
@@ -65,24 +65,24 @@
/* ---- Required Routines ---- */
/**
- * @brief Low level Touchpad driver initialization.
+ * @brief Low level Touchscreen driver initialization.
*
@@ -65,24 +65,24 @@
*
- * @param[in] tp The touchpad driver
+ * @param[in] ts The touchscreen driver struct
*
* @notapi
@@ -65,24 +65,24 @@
}
/**
- * @brief Reads a conversion from the touchpad
+ * @brief Reads a conversion from the touchscreen
*
@@ -65,24 +65,24 @@
*
- * @param[in] cmd The command bits to send to the touchpad
+ * @param[in] cmd The command bits to send to the touchscreen
*
* @return The read value 12-bit right-justified
@@ -106,18 +106,18 @@ uint16_t tp_lld_read_value(uint8_t cmd) {
}
/**
- * @brief 7-point median filtering code for touchpad samples
+ * @brief 7-point median filtering code for touchscreen samples
*
* @note This is an internally used routine only.
@@ -175,67 +175,67 @@ uint16_t tp_lld_read_x(void) {
/*
- * @brief for checking if touchpad is pressed or not.
+ * @brief for checking if touchscreen is pressed or not.
*
* @return 1 if pressed / 0 if not pressed